Signature

Struct Signature 

pub struct Signature<E: Curve> {
    pub r: NonZero<Scalar<E>>,
    pub s: NonZero<Scalar<E>>,
}
ECDSA signature

Fields

r: NonZero<Scalar<E>>

$r$ component of signature

s: NonZero<Scalar<E>>

$s$ component of signature

Implementations

Source

impl<E: Curve> Signature<E>
where NonZero<Point<E>>: AlwaysHasAffineX<E>,

pub fn verify( &self, public_key: &Point<E>, message: &dyn AnyDataToSign<E>, ) -> Result<(), InvalidSignature>

Verifies that signature matches specified public key and message

Source

impl<E: Curve> Signature<E>

pub fn from_raw_parts(r: NonZero<Scalar<E>>, s: NonZero<Scalar<E>>) -> Self

Create signature struct from r and s values

pub fn normalize_s(self) -> Self

Normilizes the signature

Given that $(r, s)$ is valid signature, $(r, -s)$ is also a valid signature. Some applications (like Bitcoin) remove this ambiguity by restricting $s$ to be in lower half. This method normailizes the signature by picking $s$ that is in lower half.

Note that signing protocol implemented within this crate ouputs normalized signature by default.

pub fn write_to_slice(&self, out: &mut [u8])

Writes serialized signature to the bytes buffer

Bytes buffer size must be at least Signature::serialized_len(), otherwise content of output buffer is unspecified.

pub fn read_from_slice(inp: &[u8]) -> Option<Self>

Reads serialized signature from the bytes buffer.

Bytes buffer size must be equal to Signature::serialized_len() and none of the signature parts should be 0. If this doesn’t hold, returns None

pub fn serialized_len() -> usize

Returns size of bytes buffer that can fit serialized signature