AnyDataToSign

Trait AnyDataToSign 

pub trait AnyDataToSign<E: Curve>:
    Send
    + Sync
    + Sealed {
    // Required method
    fn to_scalar(&self) -> Scalar<E>;
}
Data to be signed, regardless of whether original message to be signed is known or not

This library accepts &dyn AnyDataToSign only if it doesn’t matter for security whether original message is known or not.

Required Methods

fn to_scalar(&self) -> Scalar<E>

Returns a scalar that represents a data to be signed

Implementors