pub struct DataToSign<E: Curve>(/* private fields */);Expand description
A message digest that is guaranteed to have a known preimage, making it safe for signing.
This struct wraps a scalar value (Scalar<E>) that represents the cryptographic hash
of a message. It is the primary and recommended type for all signing operations in this library.
Purpose and Safety
The key security feature of DataToSign is its construction method. An instance of this struct
can only be created by providing the original message bytes to the library’s API. The library
then performs the hashing internally.
This design acts as a type-safe guard, ensuring that the system will only ever sign a hash for
which the original message (the “preimage”) is known and has been processed by the library.
This prevents a critical class of signature forgery attacks where an attacker provides a raw,
maliciously crafted hash (refer to PrehashedDataToSign docs to learn more about this attack).
Implementations
Sourceimpl<E: Curve> DataToSign<E>
impl<E: Curve> DataToSign<E>
Sourcepub fn digest<D: Digest>(data: &[u8]) -> Self
pub fn digest<D: Digest>(data: &[u8]) -> Self
Construct a DataToSign by hashing data with algorithm D
Sourcepub fn from_digest<D: Digest>(hash: D) -> Self
pub fn from_digest<D: Digest>(hash: D) -> Self
Constructs a DataToSign from output of given digest