pub struct Presignature<E: Curve> {
pub Gamma: NonZero<Point<E>>,
pub tilde_k: SecretScalar<E>,
pub tilde_chi: SecretScalar<E>,
}Expand description
Presignature, can be used to issue a partial signature without interacting with other signers
Threshold amount of partial signatures (from different signers) can be combined into regular signature
Fields
Gamma: NonZero<Point<E>>$\Gamma$ component of presignature
tilde_k: SecretScalar<E>$\tilde k_i$ component of presignature
tilde_chi: SecretScalar<E>$\tilde \chi_i$ component of presignature
Implementations
Sourceimpl<E> Presignature<E>where
E: Curve,
NonZero<Point<E>>: AlwaysHasAffineX<E>,
impl<E> Presignature<E>where
E: Curve,
NonZero<Point<E>>: AlwaysHasAffineX<E>,
Sourcepub fn issue_partial_signature(
self,
message_to_sign: DataToSign<E>,
) -> PartialSignature<E>
pub fn issue_partial_signature( self, message_to_sign: DataToSign<E>, ) -> PartialSignature<E>
Issues partial signature for given message
Never reuse presignatures! If you use the same presignatures to sign two different messages, it leaks the private key!
When signing using a presignature, it’s important that you know a message that’s being
signed (not just its hash!). For this reason, this function only accepts DataToSign that
can only be constructed when original message is known. Refer to PrehashedDataToSign
docs to learn more about possible attack when signing a hash of the message without knowing
the preimage.